import React from 'react';
import { render, screen } from '@/test-utils/index';
import { NsCollapse, AccordionVariant, ItemContent } from '@/common/index';
import { createAccordionItem3_1, getTextContent } from '../stories/data';

describe('NsCollapse', () => {
    it('1. renders children when isOpen is true', () => {
        const { getByText } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Basic}
                content={
                    <>
                        <div>Child 1</div>
                        <div>Child 2</div>
                    </>
                }
                isChild={false}
                invert={false}
                level={0}
            />
        );
        expect(getByText('Child 1')).toBeInTheDocument();
        expect(getByText('Child 2')).toBeInTheDocument();
    });
    it('2. renders children when isOpen is true and isChild is true', () => {
        const text = '1. Theme can be set';
        const content = { ...getTextContent(text) };
        const { getByText } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Basic}
                content={content}
                isChild={true}
                invert={false}
                level={0}
            />
        );
        expect(getByText(text)).toBeInTheDocument();
    });
    it('3. renders children when isOpen is true and variant is compact and content is of type accordion', () => {
        const { getByText } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Compact}
                content={createAccordionItem3_1().content}
                isChild={true}
                invert={false}
                level={0}
            />
        );
        expect(getByText('Example - 3.1.1')).toBeInTheDocument();
        expect(getByText('Example - 3.1.2')).toBeInTheDocument();
    });

    it('4. does not render children when isOpen is false', () => {
        render(
            <NsCollapse
                isOpen={false}
                variant={AccordionVariant.Basic}
                content={{
                    type: 'html',
                    data: '<h2>Lorem ipsum dolor sit amet.</h2>',
                }}
                isChild={false}
                invert={true}
                level={0}
            />
        );
        expect(screen.queryByText('Lorenm')).toBeNull();
    });
    it('5. renders html children when isOpen is true', () => {
        render(
            <NsCollapse
                isOpen={true}
                variant={AccordionVariant.Compact}
                content={{
                    type: 'html',
                    data: '<h2>Lorem ipsum dolor sit amet.</h2>',
                }}
                isChild={false}
                invert={true}
                level={0}
            />
        );
        expect(screen.queryByText('Lorem')).toBeDefined();
    });

    it('6. renders with additional class name', () => {
        const additionalClassName = 'custom-class';
        const { container } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Gray}
                content={
                    <>
                        <div>Child 1</div>
                        <div>Child 2</div>
                    </>
                }
                additionalProps={{ className: additionalClassName }}
                isChild={false}
                invert={false}
                level={7}
            />
        );
        expect(container.querySelector('section')).toHaveClass(`ns-collapse ${additionalClassName}`);
    });
    it('7. skipping allowMultipleExpanded in child data', () => {
        const { content } = createAccordionItem3_1();
        delete (content as ItemContent).allowMultipleExpanded;
        const additionalClassName = 'custom-class';
        const { container } = render(
            <NsCollapse
                isOpen
                variant={AccordionVariant.Gray}
                content={content}
                additionalProps={{ className: additionalClassName }}
                isChild={false}
                invert={true}
                level={7}
            />
        );
        expect(container.querySelector('section')).toHaveClass(`ns-collapse ${additionalClassName}`);
    });
});
