import React from 'react';

import { AccordionVariant, NsToggleSection } from '@/common/index';

import { render, fireEvent } from '@/test-utils/index';

describe('NsToggleSection', () => {
    const title = 'Toggle Section Title';
    const contentText = 'Toggle Section Content';
    const content = <div className="p-2">{contentText}</div>;
    it('1. renders title correctly', () => {
        const { getByText } = render(
            <NsToggleSection
                variant={AccordionVariant.Basic}
                title={title}
                content={content}
                invert={false}
                isChild={false}
            />
        );
        expect(getByText(title)).toBeInTheDocument();
    });
    it('2. renders title correctly', () => {
        const { getByText } = render(
            <NsToggleSection
                variant={AccordionVariant.Compact}
                title={title}
                content={content}
                invert={false}
                isChild={false}
            />
        );
        expect(getByText(title)).toBeInTheDocument();
    });

    it('2. toggles content visibility when clicked on the section header', () => {
        const { getByText, queryByText } = render(
            <NsToggleSection
                variant={AccordionVariant.Basic}
                title={title}
                content={content}
                invert={false}
                isChild={false}
            />
        );
        const el = queryByText(contentText);
        expect(el?.parentNode).toHaveStyle('opacity: 0;');

        fireEvent.click(getByText(title));
        expect(el?.parentNode).toHaveStyle('opacity: 1;');

        fireEvent.click(getByText(title));
        expect(el?.parentNode).toHaveStyle('opacity: 0;');
    });

    it('3. sets defaultOpen prop correctly', () => {
        const { getByText } = render(
            <NsToggleSection
                variant={AccordionVariant.Basic}
                title={title}
                content={content}
                invert={false}
                isChild={false}
                defaultOpen
            />
        );

        expect(getByText(contentText)).toBeInTheDocument();
    });
});
