import {ReactElement, ReactNode} from 'react';
import {AdditionalProps} from '../common.types';
import {NsIconNameType, NsIconProps} from '../icon';
import {Variants} from '../typography';
import {AccordionVariantType} from './enums';

export interface ItemContent {
    type: 'text' | 'html' | 'accordion' | 'jsx';
    allowMultipleExpanded?: boolean;
    data: string | AccordionItem[];
}

export type AccordionItem = {
    id: string;
    content: ItemContent | ReactElement;
    icon?: NsIconProps;
    title: string;
    isDefaultOpen?: boolean;
};

export type NsAccordionProps = AdditionalProps & {
    invert: boolean;
    level: number;
    variant: AccordionVariantType;
    items?: AccordionItem[];
    isChild?: boolean;
    headerTypographyVariant?: Variants;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    allowMultipleExpanded: boolean;
};

type CommonAccordionType = {
    invert: boolean;
    level: number;
    variant: AccordionVariantType;
    content: AccordionItem['content'];
};

export type NsAccordionHeaderProps = AdditionalProps & {
    title: string | ReactNode;
    // eslint-disable-next-line no-unused-vars
    onClick: (...args: any[]) => void;
    /** a flag for the header, based on which header can change properties */
    isOpen: boolean;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    headerTypographyVariant?: Variants;
    startIcon?: NsIconProps;
} & Pick<CommonAccordionType, 'invert' | 'variant'>;

export type NsCollapseProps = AdditionalProps & {
    isOpen: boolean;
    isChild: boolean;
} & CommonAccordionType;

export type NsToggleSectionProps = AdditionalProps & {
    title: string | ReactNode;
    /** if true, NsToggle is rendered in open state, that collapsible section is visible */
    defaultOpen?: boolean;
    isChild: boolean;
} & Pick<CommonAccordionType, 'invert' | 'variant' | 'content'>;

export type NsAccordionItemProps = AdditionalProps & {
    isOpen: boolean;
    // eslint-disable-next-line no-unused-vars
    toggleOpen(index: number, isOpen: boolean): void;
    title: string | ReactNode;
    headerTypographyVariant?: Variants;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    startIcon?: NsIconProps;
    isChild: boolean;
} & CommonAccordionType;
